<?php





//---------------------------------------------------------------------------------
// mm_renameField
// Change the label for an element
//---------------------------------------------------------------------------------
function mm_renameField($field, $newlabel, $roles='', $templates='', $newhelp='') {

	global $mm_fields, $modx;
	$e = &$modx->Event;
		
	// if the current page is being edited by someone in the list of roles, and uses a template in the list of templates
	if (useThisRule($roles, $templates)) {
	
	$output = " // ----------- Rename field -------------- \n";
		
			switch ($field) {
			
				// Exceptions
				case 'keywords':
					$output .= '$j("select[name*=keywords]").siblings("span.warning").empty().prepend("'.jsSafe($newlabel).'");';
				break;
				
				case 'metatags':
					$output .= '$j("select[name*=metatags]").siblings("span.warning").empty().prepend("'.jsSafe($newlabel).'");';
				break;
						
				case 'hidemenu':
					$output .= '$j("input[name=hidemenucheck]").siblings("span.warning").empty().prepend("'.jsSafe($newlabel).'");';
				break;
				
				case 'which_editor':
					$output .= '$j("#which_editor").prev("span.warning").empty().prepend("'.jsSafe($newlabel).'");';
				break;
				
				// We can't rename content box
				case 'content':
					$output .='';
				break;
			
				// Ones that follow the regular pattern
				default:
                                // Is it a TV?
				if (substr($field, 0, 2) == 'tv') {
                               $output .= '$j("#'.$field.'").parents("td").prev("td").children("span.warning").empty().prepend("'.jsSafe($newlabel).'");';}
				// What type is this field?
				else if (isset($mm_fields[$field])) {
					$fieldtype = $mm_fields[$field]['fieldtype'];
					$fieldname = $mm_fields[$field]['fieldname'];
                                        $output .= '$j("'.$fieldtype.'[name='.$fieldname.']").parents("td").prev("td").children("span.warning").empty().prepend("'.jsSafe($newlabel).'");';
				} else {
					break;
				}
				
				
				
				break;
			}	// end switch
			

			$e->output($output . "\n");
			
			// If new help has been supplied, do that too
			if ($newhelp != '') {
				mm_changeFieldHelp($field, $newhelp, $roles, $templates);
			}
			
	} // end if
} // end function






//---------------------------------------------------------------------------------
// mm_hideFields
// Hide a field
//---------------------------------------------------------------------------------
function mm_hideFields($fields, $roles='', $templates='') {

	global $mm_fields, $modx;
	$e = &$modx->Event;	
		
	// if we've been supplied with a string, convert it into an array 
	$fields = makeArray($fields);
		
	// if the current page is being edited by someone in the list of roles, and uses a template in the list of templates
	if (useThisRule($roles, $templates)) {
	
	$e->output(" // ----------- Hide fields -------------- \n");
	
		foreach ($fields as $field) {
		
			$output = '';
			
			switch ($field) {	
			
				// Exceptions
				case 'keywords':
					$output .= '$j("select[name*=keywords]").parent("td").hide();';
				break;
				
				case 'metatags':
					$output .= '$j("select[name*=metatags]").parent("td").hide()';
				break;
						
				case 'hidemenu':
					$output .= '$j("input[name=hidemenucheck]").parent("td").hide();';
				break;
						
				case 'menuindex':
					$output .= '$j("input[name=menuindex]").parents("table").parent("td").prev("td").children("span.warning").hide();' ."\n";
					$output .= '$j("input[name=menuindex]").parent("td").hide();';
				break;
				
				case 'which_editor':
					$output .= '$j("select#which_editor").prev("span.warning").hide();' . "\n";
					$output .= '$j("select#which_editor").hide();';
				break;
				
				case 'content':
					$output .= '$j("#ta").parents("div").parents("div.sectionBody").hide().prev("div.sectionHeader").hide();';
				break;
				
				case 'pub_date':
					$output .= '$j("input[name=pub_date]").parents("tr").next("tr").hide(); '."\n";
					$output .= '$j("input[name=pub_date]").parents("tr").hide(); ';
				break;
				
				case 'unpub_date':
					$output .= '$j("input[name=unpub_date]").parents("tr").next("tr").hide(); '."\n";
					$output .= '$j("input[name=unpub_date]").parents("tr").hide(); ';
				break;
			
				// Ones that follow the regular pattern
				default:	
					// Is it a TV?
					if (substr($field, 0, 2) == 'tv') {
						$output .= '$j("#'.$field.'").parents("tr").hide(); ';
					} else if (isset($mm_fields[$field]))  { // Check the fields exist,  so we're not writing JS for elements that don't exist
						$output .= '$j("'.$mm_fields[$field]['fieldtype'].'[name='.$mm_fields[$field]['fieldname'].']").parents("tr").hide(); ';
					} else {
						break;
					}				
				break;
			} // end switch
			$e->output($output . "\n");
		} // end foreach	
	} // end if
} // end function






//---------------------------------------------------------------------------------
// mm_changeFieldHelp
// Change the help text of a field
//---------------------------------------------------------------------------------
function mm_changeFieldHelp($field, $helptext='', $roles='', $templates='') {

	global $mm_fields, $modx;
	$e = &$modx->Event;	
		
	if ($helptext=='') {
		return;
	}
	
	// if the current page is being edited by someone in the list of roles, and uses a template in the list of templates
	if (useThisRule($roles, $templates)) {
	
	$output = " // ----------- Change field help -------------- \n";
	
			switch ($field) {
			
				// Exceptions
				case 'parent':
					$output .= '$j("input[name=parent]").siblings("span.comment").empty().prepend("'.jsSafe($helptext).'"); ';
				break;
				
				// Ones that follow the regular pattern
				default:
				// Is it a TV?
			        if (substr($field, 0, 2) == 'tv') {
$output .= '$j("#'.$field.'").parents("td").prev("td").children("span.comment").empty().prepend("'.jsSafe($helptext).'");';

                                }
				// What type is this field?
				else if (isset($mm_fields[$field])) {
					$fieldtype = $mm_fields[$field]['fieldtype'];
					$fieldname = $mm_fields[$field]['fieldname'];
                                        $output .= '$j("'.$fieldtype.'[name='.$fieldname.']").siblings("img[style:contains(\'cursor:help\')]").attr("alt", "'.jsSafe($helptext).'"); ';
				} else {
					break;
				}
				
				
				
				break;
			} // end switch
			$e->output($output . "\n");
	} // end if
} // end function










//---------------------------------------------------------------------------------
// mm_moveFieldsToTab
// Move a field to a different tab
//--------------------------------------------------------------------------------- 
function mm_moveFieldsToTab($fields, $newtab, $roles='', $templates='') {

	global $modx, $mm_fields;
	$e = &$modx->Event;
	
	// if we've been supplied with a string, convert it into an array 
	$fields = makeArray($fields);
			
	// if the current page is being edited by someone in the list of roles, and uses a template in the list of templates
	if (useThisRule($roles, $templates)) {
	
	$output = " // ----------- Move field to tab -------------- \n";
	
		// If it's one of the default tabs, we need to get the capitalisation right
		switch ($newtab) {
			case 'general':
			case 'settings':
			case 'meta':
			case 'preview':
				$newtab = ucfirst($newtab);
			break;
		}
		
		// Make sure the new tab exists in the DOM
		$output .= "if ( \$j('#tab".$newtab."').length > 0) { \n";
			
		// Go through each field that has been supplied
		foreach ($fields as $field) {

			switch ($field) {
			
				// We can't move these fields because they belong in a particular place
				case 'keywords':
				case 'metatags':
				case 'which_editor':
				case 'content':
				case 'hidemenu':
				case 'menuindex':
				break;
				
				case 'pub_date':
					$output .= 'var helpline = $j("input[name=pub_date]").parents("tr").next("tr").appendTo("#tab'.$newtab.'>table:first"); ' . "\n";
					$output .= '$j(helpline).before($j("input[name=pub_date]").parents("tr")); ' . "\n";
					// Required to prevent JS error, because JS calendar is trying to do stuff to pub_date_show element, which doesn't exist
					$output .= '$j("body").prepend("<span id=\"pub_date_show\"></span>"); cal1.txt_target=$j("#pub_date_show"); ' . "\n"; 
					break;

				case 'unpub_date':
					$output .= 'var helpline = $j("input[name=unpub_date]").parents("tr").next("tr").appendTo("#tab'.$newtab.'>table:first"); ' . "\n";
					$output .= '$j(helpline).before($j("input[name=unpub_date]").parents("tr")); ' . "\n";
					// Required to prevent JS error, because JS calendar is trying to do stuff to unpub_date_show element, which doesn't exist
					$output .= '$j("body").prepend("<span id=\"unpub_date_show\"></span>"); cal2.txt_target=$j("#unpub_date_show"); ' . "\n"; 
					break;
			
				
				default:
				
					// What type is this field?
					if (isset($mm_fields[$field])) {
						$fieldtype = $mm_fields[$field]['fieldtype'];
						$fieldname = $mm_fields[$field]['fieldname'];
						$output .= '$j("'.$fieldtype.'[name='.$fieldname.']").parents("tr").appendTo("#tab'.$newtab.'>table:first"); ' . "\n";
					} else {	// If we don't know about it, it is most likely a template variable, expecially if it begins with tv
						if (substr($field, 0, 2) == 'tv') {
//$field = "tv".$modx->db->getValue("SELECT id FROM ".$modx->getFullTableName('site_tmplvars')." WHERE name='".substr($field, 2)."'");
							$output .= 'var tv = $j("[name^='.$field.']:first").parents("tr"); ' . "\n";
							$output .= '$j(tv).next("tr").remove(); ' . "\n"; // remove the dotted line
							$output .= 'var newTV = $j(tv).appendTo("#tab'.$newtab.'>table:first"); ' . "\n";
							$output .= '$j(newTV).after(\'<tr style="height: 10px"><td colspan="2"><div class="split"></div></td></tr>\'); ';
							// This prevents an IE6/7 bug where the moved field would not be visible until you switched tabs
							$output .= '$j("[name^='.$field.']:first").parents("td").removeAttr( "style" ); ';
						} else {	// if it's not a template variable, don't deal with it
							break;
						}
					}	
								
						
				break;
			
			} // end switch	
		} // end foreach
		
		$output .= "}";
		$e->output($output . "\n");
		
	}	// end if
} // end function









?>
