<?php
/*
    @name       ManagerManager
    @version    0.3.2, 2008-11-05
    
    @for        MODx 0.9.6
    
    @author     Nick Crossland - www.rckt.co.uk
    
    @DESCRIPTION
    Used to manipulate the display of document fields in the manager.
    
    @INSTALLATION:
    1. Download jquery.js from http://jquery.com/src/jquery-latest.pack.js
    2. Put it in /assets/js/
	3. In ModX manager, create a new plugin and paste in the code from plugin.txt
	4. In the "system events" tab, check the OnDocFormRender and OnDocFormPrerender checkboxes
	5. Put this file in /assets/plugins/managermanager (if you want to put it somewhere else, you'll need to change the path in the plugin text you pasted in step 3) 
    6. Insert your rules into the marked section within the plugin code in the manager
    
    @INSPIRATION:
    HideEditor plugin by Timon Reinhard and Gildas; HideManagerFields by Brett @ The Man Can!
	
	@LICENSE:
	(c) Rocket Science Solutions Ltd - www.rckt.co.uk	
	Released under the GNU General Public License: http://creativecommons.org/licenses/GPL/2.0/
	
*/

$mm_version = '0.3.2';

// When loading widgets / functions, ignore folders / files beginning with these chars
$ignore_first_chars = array('.', '_', '!'); 

// Include functions - we'll load all *.inc.php files in the "functions" folder
$function_dir = $modx->config['base_path'] . 'assets/plugins/managermanager/functions';
if ($handle = opendir($function_dir)) {
    while (false !== ($file = readdir($handle))) {
        if (!in_array(substr($file, 0, 1), $ignore_first_chars) && $file != ".." && substr($file, -8) == '.inc.php') {
            include_once($function_dir.'/'.$file);
        }
    }
    closedir($handle);
}

// Include widgets
// We look for a PHP file with the same name as the directory - e.g.
// /widgets/widgetname/widgetname.php
$widget_dir = $modx->config['base_path'] . 'assets/plugins/managermanager/widgets';
if ($handle = opendir($widget_dir)) {
    while (false !== ($file = readdir($handle))) {
        if (!in_array(substr($file, 0, 1), $ignore_first_chars)  && $file != ".."  && is_dir($widget_dir.'/'.$file)) {
            include_once($widget_dir.'/'.$file.'/'.$file.'.php');
        }
    }
    closedir($handle);
}



// Set variables
global $content,$default_template, $mm_current_page, $mm_fields;
$mm_current_page = array();
$mm_current_page['template'] = isset($_POST['template']) ? $_POST['template'] : isset($content['template']) ? $content['template'] : $default_template;
$mm_current_page['role'] = $_SESSION['mgrRole'];


// What are the fields we can change, and what types are they?
$mm_fields = array(
	'pagetitle' => array('fieldtype'=>'input', 'fieldname'=>'pagetitle'),
	'longtitle' => array('fieldtype'=>'input', 'fieldname'=>'longtitle'),
	'description' => array('fieldtype'=>'input', 'fieldname'=>'description'),
	'alias' => array('fieldtype'=>'input', 'fieldname'=>'alias'),
	'link_attributes' => array('fieldtype'=>'input', 'fieldname'=>'link_attributes'),
	'introtext' => array('fieldtype'=>'textarea', 'fieldname'=>'introtext'), 
	'template' => array('fieldtype'=>'select', 'fieldname'=>'template'),  
	'menutitle' => array('fieldtype'=>'input', 'fieldname'=>'menutitle'),
	'menuindex' => array('fieldtype'=>'input', 'fieldname'=>'menuindex'),
	'show_in_menu' => array('fieldtype'=>'input', 'fieldname'=>'hidemenucheck'),
	'parent' => array('fieldtype'=>'input', 'fieldname'=>'parent'),
	'is_folder' => array('fieldtype'=>'input', 'fieldname'=>'isfoldercheck'),
	'is_richtext' => array('fieldtype'=>'input', 'fieldname'=>'richtextcheck'),
	'log' => array('fieldtype'=>'input', 'fieldname'=>'donthitcheck'),
	'published' => array('fieldtype'=>'input', 'fieldname'=>'publishedcheck'),
	'pub_date' => array('fieldtype'=>'input', 'fieldname'=>'pub_date'),
	'unpub_date' => array('fieldtype'=>'input', 'fieldname'=>'unpub_date'),
	'searchable' => array('fieldtype'=>'input', 'fieldname'=>'searchablecheck'),
	'cacheable' => array('fieldtype'=>'input', 'fieldname'=>'cacheablecheck'),
	'clear_cache' => array('fieldtype'=>'input', 'fieldname'=>'syncsitecheck'),
	'content_type' => array('fieldtype'=>'select', 'fieldname'=>'contentType'),
	'content_dispo' => array('fieldtype'=>'select', 'fieldname'=>'content_dispo'),
	'keywords' => array('fieldtype'=>'select', 'fieldname'=>'keywords[]'),
	'metatags' => array('fieldtype'=>'select', 'fieldname'=>'metatags[]'),
	'content' => array('fieldtype'=>'textarea', 'fieldname'=>'content'),
	'which_editor' => array('fieldtype'=>'select', 'fieldname'=>'which_editor'),
	'weblink' => array('fieldtype'=>'input', 'fieldname'=>'ta')
);				



// Get the contents of the config chunk, and put it in the "make changes" function, to be run at the appropriate moment later on
if (!function_exists("make_changes")) {
	function make_changes($chunk) { 
	
		global $modx;	// Global modx object
		$config_file = $modx->config['base_path'] . 'assets/plugins/managermanager/mm_rules.inc.php';
		
		// See if there is any chunk output (e.g. it exists, and is not empty)
		$chunk_output = $modx->getChunk($chunk);
		if (!empty($chunk_output)) {
			eval($chunk_output); // If there is, run it.
			return;
		} else if (is_readable($config_file)) {	// If there's no chunk output, read in the file.
			include($config_file);
		}
	} 
} 




// Check the current event
global $e;
$e = &$modx->Event;



// The start of adding or editing a document (before the main form)
switch ($e->name) { 


// if it's the plugin config form, give us a copy of all the relevant values

case 'OnChunkFormRender':
	
	$chunk_id_editing = $e->params['id']; // The ID of the chunk we're editing
	$result = $modx->db->select("name, id", $modx->db->config['table_prefix']."site_htmlsnippets", "id=$chunk_id_editing");
	$all_chunks = $modx->db->makeArray( $result );
	$chunk_editing_name = $all_chunks[0]['name'];

 
	
	// if it's the right plugin
	if (strtolower($chunk_editing_name) == $config_chunk) {
	
		// Get all templates
		$result = $modx->db->select("templatename, id, description", $modx->db->config['table_prefix']."site_templates", '', 'templatename ASC');
		$all_templates = $modx->db->makeArray( $result );
		$template_table = '<table>';
		$template_table .= '<tr><th class="gridHeader">Template name</th><th class="gridHeader">Template description</th><th class="gridHeader">ID</th></tr>';
		$template_table .= '<tr><td class="gridItem">(blank)</td><td class="gridItem">Blank</td><td class="gridItem">0</td></tr>';
		foreach ($all_templates as $count=>$tpl) {
			$class = ($count % 2) ? 'gridItem':'gridAltItem';
			$template_table .= '<tr>';
			$template_table .= '<td class="'.$class.'">'.jsSafe($tpl['templatename']).'</td>';
			$template_table .= '<td class="'.$class.'">'.jsSafe($tpl['description']).'</td>';
			$template_table .= '<td class="'.$class.'">'.$tpl['id'].'</td>';
			$template_table .= '</tr>';
		}
		$template_table .= '</table>';

// Get all tvs
		$result = $modx->db->select("name,caption,id", $modx->db->config['table_prefix']."site_tmplvars", '', 'name ASC');
		$all_tvs = $modx->db->makeArray( $result );
		$tvs_table = '<table>';
		$tvs_table .= '<tr><th class="gridHeader">TV name</th><th class="gridHeader">TV caption</th><th class="gridHeader">ID</th></tr>';
		
		foreach ($all_tvs as $count=>$tv) {
			$class = ($count % 2) ? 'gridItem':'gridAltItem';
			$tvs_table .= '<tr>';
			$tvs_table .= '<td class="'.$class.'">'.jsSafe($tv['name']).'</td>';
			$tvs_table .= '<td class="'.$class.'">'.jsSafe($tv['caption']).'</td>';
			$tvs_table .= '<td class="'.$class.'">'.$tv['id'].'</td>';
			$tvs_table .= '</tr>';
		}
		$tvs_table .= '</table>';
		
		
		// Get all roles
		$result = $modx->db->select("name, id", $modx->db->config['table_prefix']."user_roles", '', 'name ASC');
		$all_roles = $modx->db->makeArray( $result );
		$roles_table = '<table>';
		$roles_table .= '<tr><th class="gridHeader">Role name</th><th class="gridHeader">ID</th></tr>';
		foreach ($all_roles as $count=>$role) {
			$class = ($count % 2) ? 'gridItem':'gridAltItem';
			$roles_table .= '<tr>';
			$roles_table .= '<td class="'.$class.'">'.jsSafe($role['name']).'</td>';
			$roles_table .= '<td class="'.$class.'">'.$role['id'].'</td>';
			$roles_table .= '</tr>';
		}
		$roles_table .= '</table>';
			
		$output = '<div class="sectionBody">';
		$output .= '<table><tr><td style="vertical-align:top">';		
		$output .= $template_table;
                $output .='</td><td style="vertical-align:top">';
                $output .= $tvs_table;
                $output .='</td><td style="vertical-align:top">';
                $output .= $roles_table;
                $output .='</td></tr></table>';
                $output .='</div>';
		$e->output($output);
		
	} 
	break;




case 'OnDocFormPrerender':

	// Are we clashing with the ShowImageTVs (or any other) plugins?
	//$conflicted_plugins = array('ShowImageTVs');
	//$conflicts = array();
	//foreach ($conflicted_plugins as $plg) {
		
	//	$sql= "SELECT * FROM " . $this->getFullTableName("site_plugins") . " WHERE name='" . $plg . "' OR name='" . strtolower($plg) . "'AND disabled=0;";
       // $result= $modx->db->query($sql);
       //	if ($modx->db->getRecordCount($result) > 0) {
       //	$conflicts[] = $plg;
	//	}
	//}
	//if (count($conflicts) > 0) {
	//	echo '		
	//	<script type="text/javascript">
	//		alert("You appear to be running '.(count($conflicts)>1?'some plugins which are':'a plugin which is').' incompatible with ManagerManager: \n\n  '.implode('  \n  ', $conflicts).'\n\nYou may experience errors or unpredictable behaviour. \n\nPlease see the ManagerManager documentation for details of how to fix this.");
	//	</script>	
	//	';	
	//}
	

	// Load the jquery library
	echo includeJquery($js_url);
	

	// Create a mask to cover the page while the fields are being rearranged
	echo '		
		<div id="loadingmask">&nbsp;</div>
		<script type="text/javascript">
		var $j = jQuery.noConflict();

			$j("#loadingmask").css( {width: "100%", height: $j("body").height(), position: "absolute", zIndex: "1000", backgroundColor: "#ffffff"} );
		</script>	
	';
	break;
	
	

case 'OnDocFormRender':
	
	// The main document editing form
	

    // Include the JQuery call
    $e->output( '
<!-- ManagerManager Plugin :: '.$mm_version.' -->
<!-- This document is using template: '. $mm_current_page['template'] .' -->
<!-- You are logged into the following role: '. $mm_current_page['role'] .' -->
		
<script type="text/javascript" charset="'.$modx->config['modx_charset'].'">
var $j = jQuery.noConflict();
		
mm_lastTab = "tabGeneral"; 
mm_sync_field_count = 0;
synch_field = new Array();

$j(document).ready(function() {
	
	// Lets handle errors nicely...
	try {
						   					
		// Give IDs to the sections of the form
		// This assumes they appear in a certain order
		//$j("div.sectionHeader:eq(0)").attr("id", "sectionDocSettingsHeader");
		$j("div.sectionHeader:eq(0)").attr("id", "sectionContentHeader");
		$j("div.sectionHeader:eq(1)").attr("id", "sectionTVsHeader");
		$j("div.sectionHeader:eq(2)").attr("id", "sectionAccessHeader");
		
		$j("div.sectionBody:eq(0)").attr("id", "sectionDocSettingsBody");
		$j("div.sectionBody:eq(1)").attr("id", "sectionContentBody");
		$j("div.sectionBody:eq(2)").attr("id", "sectionTVsBody");
		$j("div.sectionBody:eq(3)").attr("id", "sectionAccessBody");								   
			'			
			);
	
	
	// Get the JS for the changes
  	
		// Where would we get the config file from?
		$config_file = $modx->config['base_path'] . 'assets/plugins/managermanager/mm_rules.inc.php';
			
		// See if there is any chunk output (e.g. it exists, and is not empty)
		$chunk_output = $modx->getChunk($config_chunk);
		if (!empty($chunk_output)) {
			$e->output("// Getting rules from chunk: $config_chunk \n\n");
			eval($chunk_output); // If there is, run it.
		} else if (is_readable($config_file)) {	// If there's no chunk output, read in the file.
			$e->output("// Getting rules from file: $config_file \n\n");
			include($config_file);
		} else {
			$e->output("// No rules found \n\n");
		}
		
	
    
    // Close it off
    $e->output( '	
	
		// Misc tidying up
		
		// General tab table container is too narrow for receiving TVs -- make it a bit wider
		$j("div#tabGeneral table").attr("width", "550");
		
		// if template variables containers are empty, remove their section
		if ($j("div.tmplvars :input").length == 0) {
			$j("div.tmplvars").hide();	// Still contains an empty table and some dividers
			$j("#sectionTVsHeader").hide(); 
		}
	
	} catch (e) {
		// If theres an error, fail nicely
		alert("ManagerManager: An error has occurred: " + e.name + " - " + e.message);	
		
	} finally {	
		
		// Whatever happens, hide the loading mask
		$j("#loadingmask").hide();
	}
});
</script>
<!-- ManagerManager Plugin :: End -->
		');
	break;



} // end switch



?>
